pritunl-client: pritunl vpn client
==================================

.. image:: http://gitshields.com/v2/pypi/pritunl_client/version/7d0ce8.png
    :target: https://pypi.python.org/pypi/pritunl_client

.. image:: http://gitshields.com/v2/pypi/pritunl_client/month_down/ff4a20.png
    :target: https://pypi.python.org/pypi/pritunl_client

.. image:: http://gitshields.com/v2/text/license/AGPLv3/blue.png
    :target: https://www.gnu.org/licenses/agpl-3.0.html

`Pritunl-Client <https://github.com/pritunl/pritunl-client>`_ is an open
source vpn client for Pritunl. Documentation and more information can be
found at the home page `pritunl.com <http://pritunl.com>`_
